@@ -1,7 +1,7 @@
 /*
  *   This file is part of the MLV Library.
  *
- *   Copyright (C) 2010 Adrien Boussicault, Marc Zipstein
+ *   Copyright (C) 2010,2011,2012 Adrien Boussicault, Marc Zipstein
  *
  *
  *    This Library is free software: you can redistribute it and/or modify
@@ -31,14 +31,14 @@
 #include "warning_error.h"
 #include "memory_management.h"
 
-int MLV_boolean_random(int begin, int end){
+int MLV_get_random_boolean(int begin, int end){
 	return g_random_boolean( );
 }
 
-int MLV_integer_random(int begin, int end){
+int MLV_get_random_integer(int begin, int end){
 	return g_random_int_range( begin, end );
 }
 
-double MLV_double_random(double begin, double end){
+double MLV_get_random_double(double begin, double end){
 	return g_random_double_range( begin, end );
 }
